pub struct CanFrame {
pub id: CanId,
pub data: Vec<u8, 8>,
}Expand description
A simple owned CAN frame for use in the platform-agnostic layer.
Fields
id: CanIddata: Vec<u8, 8>Trait Implementations
impl Eq for CanFrame
Sourceimpl Frame for CanFrame
impl Frame for CanFrame
Sourcefn new_remote(_id: impl Into<Id>, _dlc: usize) -> Option<Self>
fn new_remote(_id: impl Into<Id>, _dlc: usize) -> Option<Self>
Creates a new remote frame (RTR bit set). Read more
Sourcefn is_extended(&self) -> bool
fn is_extended(&self) -> bool
Returns true if this frame is a extended frame.
Sourcefn is_remote_frame(&self) -> bool
fn is_remote_frame(&self) -> bool
Returns true if this frame is a remote frame.
Sourcefn dlc(&self) -> usize
fn dlc(&self) -> usize
Returns the data length code (DLC) which is in the range 0..8. Read more
Sourcefn is_standard(&self) -> bool
fn is_standard(&self) -> bool
Returns true if this frame is a standard frame.
Sourcefn is_data_frame(&self) -> bool
fn is_data_frame(&self) -> bool
Returns true if this frame is a data frame.
impl StructuralPartialEq for CanFrame