pub fn env_sanitize(s: &str) -> boolExpand description
Sanitizes environment variable input by checking for valid ASCII graphic characters.
Returns true if the input contains at least one character and all characters
are ASCII graphic characters (printable characters excluding space).