parse_pubkey

Function parse_pubkey 

pub fn parse_pubkey(value: &str) -> Option<&str>
Validates a public key environment value.

This accepts printable ASCII, including spaces, as the format for a key expects <type> <base64> [comment]. This would be rejected by env_sanitize which is stricter, so it is separated out here for pubkey environment variables only.