ssh_client

Function ssh_client 

pub async fn ssh_client<'a, 'b, U, P>(
    uart_buff: &'a U,
    ssh_server: &'b SSHServer<'a>,
    chan_pipe: &'b Channel<NoopRawMutex, SessionType, 1>,
    platform: &'b P,
    can_queue: &'b Channel<NoopRawMutex, ChanHandle, 1>,
) -> Result<(), Error>
Handles an SSH client connection, bridging UART and SSH.

A can subsystem channel is bridged concurrently with the shell (UART) session on the same connection. The whole connection is torn down when either bridge finishes.

Errors

Returns an error if SSH protocol operations or I/O fail.